#!/bin/bash
#
#  (C) 2010 Sonic Solutions. Portions (C) 1989-2010 EMC Corporation. All rights reserved.
#

#
#  Change this if you've installed java somewhere else
#
JAVA_HOME=/usr/bin

#
# leave HOST blank for localhost 
# DISPLAYNUMBER is 0 by default
# SCREEN blank or 0 by default
#
HOST=
DISPLAYNUMBER=0
SCREEN=0

if [ $# != 0 ]
then
	[ -z $DISPLAY ] && export DISPLAY=$HOST:$DISPLAYNUMBER.$SCREEN
	export Arg1=$1
else
	export Arg1=""
fi

rm -f /tmp/retrospect_status								# status for client
rm -f /tmp/RetroClient.status								# status for user

# 
#  Check if java is installed and if JAVA_HOME points to the correct location.
#  If not, then exit with a 0 status, telling the server to go ahead and do
#  the backup.
#
if [ ! -f $JAVA_HOME/java ]; then
	if [ -z $Arg1 ]; then									# launching control panel
		echo "JAVA_HOME is set to an invalid location"
		echo "JAVA_HOME=$JAVA_HOME"
	fi
	echo 0 > /tmp/retrospect_status
	exit
fi
	
#
#  Set up environment variable RETROSPECT_HOME so the GUI can be 
#  launched after installation.
#
if [ -z $RETROSPECT_HOME ]
then
	RETROSPECT_HOME=`grep RETROSPECT_HOME /etc/profile | grep = | cut -c17-999`
	export RETROSPECT_HOME
fi

#
#  Make sure that the necessary environment variables are set.  
#  If they're not, then exit with a 0 status, telling the server
#  to go ahead and do the backup
#
if [ -z $RETROSPECT_HOME ] || [ -z $DISPLAY ]
then
	echo "either RETROSPECT_HOME or DISPLAY not set!" > /tmp/RetroClient.status
	echo "RETROSPECT_HOME=$RETROSPECT_HOME" >> /tmp/RetroClient.status
	echo "DISPLAY=$DISPLAY" >> /tmp/RetroClient.status

	echo "either RETROSPECT_HOME or DISPLAY not set!"
	echo "RETROSPECT_HOME=$RETROSPECT_HOME"
	echo "DISPLAY=$DISPLAY"

	echo 0 > /tmp/retrospect_status
	exit
fi

#
#  Make sure that RETROSPECT_HOME has the stuff we need in it.
#  If not, exit as above
#
if [ ! -f $RETROSPECT_HOME/retrospect.jar ] ||
   [ ! -f $RETROSPECT_HOME/retrocpl ]
then
	echo "Critical file missing!" > /tmp/RetroClient.status

	echo "Critical file missing!"

	echo `ls -laF RETROSPECT_HOME/retrospect.jar`
	echo `ls -laF RETROSPECT_HOME/retrocpl`
	echo 0 > /tmp/retrospect_status
	exit
fi

echo "Executing java with the following: " > /tmp/RetroClient.status
echo "RETROSPECT_HOME=$RETROSPECT_HOME" >> /tmp/RetroClient.status
echo "DISPLAY=$DISPLAY" >> /tmp/RetroClient.status

cd $RETROSPECT_HOME

# Fix virtual binding warnings on Red Hat 7.3.
CLIENTMACHINE=`uname`
if [ $CLIENTMACHINE = "Linux" ]; then
	xprop -root -remove _MOTIF_DEFAULT_BINDINGS
fi

if [ -z $Arg1 ] 
then
	echo "Executing no arguments mode" >> /tmp/RetroClient.status
	$JAVA_HOME/java -DretrocplPath=$RETROSPECT_HOME/retrocpl -Djava.library.path=$RETROSPECT_HOME -jar $RETROSPECT_HOME/retrospect.jar $1 "$2" "$3" $4
else
	if [ $Arg1 = "notify_backup" ]
	then
		echo "Executing notify_backup mode" >> /tmp/RetroClient.status
		$JAVA_HOME/java -DretrocplPath=$RETROSPECT_HOME/retrocpl -Djava.library.path=$RETROSPECT_HOME -jar $RETROSPECT_HOME/retrospect.jar $1 "$2" "$3" $4 &
	else
		echo "Executing countdown timer mode" >> /tmp/RetroClient.status
		$JAVA_HOME/java -DretrocplPath=$RETROSPECT_HOME/retrocpl -Djava.library.path=$RETROSPECT_HOME -jar $RETROSPECT_HOME/retrospect.jar $1 "$2" "$3" $4
	fi
fi

RETROSPECT_JAVA_STATUS=$?
echo $RETROSPECT_JAVA_STATUS > /tmp/retrospect_status
