#!/bin/bash

# Retrospect Client Install script 
# 6/2002 
# 
# (C) 2010 Sonic Solutions. Portions (C) 1989-2010 EMC Corporation. All rights reserved.
# www.retrospect.com

# Global settings

CLIENTDIR=/usr/local/dantz/client

###############################################################################
# Prompts used in script
###############################################################################

NOTROOTMESSAGE="Sorry, installation requires that you be logged on as root."
USRLOCALDIRECTORYMISSINGMESSAGE="Sorry, installation requires that a /usr/local directory already exist."
UNSUPPORTEDOSMESSAGE="Sorry, this is not a supported operating system."
INSTALLINGMESSAGE="Installing Retrospect Client..."
ADDINGRETROSPECTHOMEMESSAGE="Adding RETROSPECT_HOME to system profile and login scripts..."
FINISHEDWITHRETROSPECTHOMEMESSAGE=\
"Done!\n
\n
Before attempting to use any of the GUI components of the Retrospect Client,\n
you must have both the RETROSPECT_HOME and DISPLAY variables set.  The\n
RETROSPECT_HOME variable should point to $CLIENTDIR.  We have\n
modified your /etc/profile and /etc/.login files to set this value for future\n
logins.  The retrospect client launched as part of this installation process\n
will also have this variable set.  However, if you kill that client and\n
restart it without logging out, you will need to set these variables manually.\n
"
STARTINGCLIENTMESSAGE="Starting client as daemon... "
CLIENTSTARTEDMESSAGE="Retrospect Client started successfully!"
CLIENTNOSTARTMESSAGE=\
"Installation was successful, but Retrospect Client could not be started.\n
If this is an upgrade, please wait 5 minutes, then start the client manually\n
by running  $ $CLIENTDIR/rcl start"
UPGRADESUCCESSMESSAGE="Upgrade completed successfully"
SOLARISNORCMESSAGE=\
"You should install a startup script in /etc/rc3.d named S99retroclient\n
to start the Retrospect Client for Solaris automatically when you\n
boot your system.  See your system documentation for more information."
INSTALLSUCCESSFULMESSAGE="Installation completed successfully"
PRESSENTERMESSAGE="Press \"Enter\" to close this window."
LINUXNORCMESSAGE=\
"If your system uses an rc.local script, you should be able to start\n
the Retrospect Client automatically by adding the line\n
'$CLIENTDIR/rcl start'. Otherwise, consult your system\n
documentation for the best method."

#  Get the system architecture

KERNELNAME=`uname`
if [ $KERNELNAME = "SunOS" ]; then
###############################################################################
# Perform SunOS installation.
###############################################################################
   
    # Make sure we are root.

    MYNAME=`/usr/ucb/whoami`
    if [ $MYNAME != "root" ]; then
        echo
        echo $NOTROOTMESSAGE
        exit 0
    fi

    # Make sure /usr/local exists.

    if [ ! -d "/usr/local" ]; then 
        echo
        echo $USRLOCALDIRECTORYMISSINGMESSAGE
        exit 0
    fi

    LD_LIBRARY_PATH="/usr/local/lib:/usr/openwin/lib"
    export LD_LIBRARY_PATH

    echo
    echo $INSTALLINGMESSAGE

    # Stop the client if it is running

    UPGRADE=""
    RUNNING=`/usr/bin/pgrep -x -u root retroclient`
    if [ $RUNNING ]; then
        UPGRADE=TRUE
        $CLIENTDIR/retrocpl -stop > /dev/null 
    fi

    # rcl is unpacked to CLIENTDIR so always need to move it to /etc

    STATEFILE=/var/log/retroclient.state

    /usr/bin/mv -f $CLIENTDIR/rcl /etc/rc3.d/S99retroclient
    ln -sf /etc/rc3.d/S99retroclient $CLIENTDIR/rcl
    if [ ! -f $STATEFILE ]; then
        $CLIENTDIR/retroclient -setpass
    fi

    # Install miscellaneous files
    cp -f /usr/local/man/man1/retrocpl.1 /usr/man/man1
    cp -f /usr/local/man/man1/retroclient.1 /usr/man/man1

    if [ ! -f "/etc/retroclient.excludes" ]; then
        /bin/mv $CLIENTDIR/retroclient.excludes /etc 
    else
        /bin/rm $CLIENTDIR/retroclient.excludes	
    fi

    #  Set up the environment variables

    #  Bash/sh first
    echo ""
    /usr/ucb/echo -n $ADDINGRETROSPECTHOMEMESSAGE

    if [ -f /etc/profile ]; then
        ISTHERE=`grep RETROSPECT_HOME /etc/profile`
        if [ ! -z "$ISTHERE" ]; then
            cp /etc/profile /etc/profile.old
            sed -e "/RETROSPECT_HOME/d" < /etc/profile.old > /etc/profile
        fi
        echo "RETROSPECT_HOME=$CLIENTDIR" >> /etc/profile
        echo "export RETROSPECT_HOME" >> /etc/profile
    fi

    #  csh now
    if [ -f /etc/.login ]; then
        ISTHERE=`grep RETROSPECT_HOME /etc/.login`
        if [ ! -z "$ISTHERE" ]; then
            cp /etc/.login /etc/.login.old
            sed -e "/RETROSPECT_HOME/d" < /etc/.login.old > /etc/.login
        fi
        echo "setenv RETROSPECT_HOME $CLIENTDIR" >> /etc/.login
    fi
    echo $FINISHEDWITHRETROSPECTHOMEMESSAGE

    # Start the client as a daemon

    echo $STARTINGCLIENTMESSAGE
    RETROSPECT_HOME="$CLIENTDIR"
    export RETROSPECT_HOME
    OSTYPE="solaris"
    export OSTYPE 
    $CLIENTDIR/rcl start &
    echo    
    sleep 1
    RUNNINGCOUNT=`/usr/bin/ps -ef | grep retroclient | /usr/bin/grep -v grep | /usr/bin/grep -c retro`
    if [ $RUNNINGCOUNT -gt 0 ]; then
        echo $CLIENTSTARTEDMESSAGE
    else
        echo $CLIENTNOSTARTMESSAGE
    fi
    if [ $UPGRADE ]; then
        echo $UPGRADESUCCESSMESSAGE
    else
        if [ -d "/etc/rc3.d" ] && [ ! -f "/etc/rc3.d/S99retroclient" ]; then
            for Y in 2 3 5; do
                ln -s $CLIENTDIR/rcl /etc/rc.d/rc$Y.d/S99retroclient
            done
        elif [ ! -d "/etc/rc3.d" ]; then
            echo $SOLARISNORCMESSAGE
        else
            echo $INSTALLSUCCESSFULMESSAGE
        fi
    fi

    # Give a friendly message to hit enter to close the window.

    echo
    if [ "$(ps -e | grep xterm)" ]; then
        /usr/ucb/echo -n $PRESSENTERMESSAGE
        read X
        if [ "$X" ]; then
            exit 0
        fi
    fi
    exit 0
elif [ $KERNELNAME = "Linux" ]; then
###############################################################################
# Perform Linux installation.
###############################################################################

    # Make sure we are root.

    if [ "$UID" -ne 0 ]; then
        echo
        echo $NOTROOTMESSAGE
        exit 0
    fi

    # Make sure /usr/local exists.

    if [ ! -d "/usr/local" ]; then 
        echo
        echo $USRLOCALDIRECTORYMISSINGMESSAGE
        exit 0
    fi

    echo
    echo $INSTALLINGMESSAGE

    # Stop the client if it is running

    UPGRADE=""
    if [ -x /sbin/pidof ] && [ "$(/sbin/pidof retroclient)" ] || [ "$(ps -e | grep retroclient)" ]; then
        UPGRADE=TRUE
        $CLIENTDIR/retrocpl -stop > /dev/null 
    fi

    # Install miscellaneous files

    if  [ -L /usr/share/info/dir ]; then
        INFODIRFILE=/etc/info-dir
    else
        INFODIRFILE=/usr/share/info/dir
    fi
    cat<< EOF >> $INFODIRFILE

Retrospect Client 
* retroclient: (retroclient).					Retrospect Client.
* retrocpl: (retroclient)retrocpl.				Retrospect Client Control Panel.
EOF

    #  Set up the environment variables

    #  Bash/sh first
    echo ""
    echo -n $ADDINGRETROSPECTHOMEMESSAGE

    if [ -f /etc/profile ]; then
        ISTHERE=`grep RETROSPECT_HOME /etc/profile`
        if [ ! -z "$ISTHERE" ]; then
            cp /etc/profile /etc/profile.old
            sed -e "/RETROSPECT_HOME/d" < /etc/profile.old > /etc/profile
        fi
        echo "RETROSPECT_HOME=$CLIENTDIR" >> /etc/profile
        echo "export RETROSPECT_HOME" >> /etc/profile
    fi

    #  csh now
    if [ -f /etc/.login ]; then
        ISTHERE=`grep RETROSPECT_HOME /etc/.login`
        if [ ! -z "$ISTHERE" ]; then
            cp /etc/.login /etc/.login.old
            sed -e "/RETROSPECT_HOME/d" < /etc/.login.old > /etc/.login
        fi
        echo "setenv RETROSPECT_HOME $CLIENTDIR" >> /etc/.login
    fi
    echo -e $FINISHEDWITHRETROSPECTHOMEMESSAGE


    # Check for Linux Standard Base compliance.
    # For more information see: http://www.linuxbase.org
    # For a list of certified LSB Linux distributions see: http://www.linuxbase.org/test/registered.html
    if lsb_release 2> /dev/null && [ `lsb_release -s 2> /dev/null` != "n/a" ] && [ -x /usr/lib/lsb/install_initd ] && [ -x /usr/lib/lsb/remove_initd ]; then
        LSBSYSTEM=TRUE
    else
        LSBSYSTEM=""
    fi

    # rcl is unpacked to CLIENTDIR so always need to move it to /etc

    INITD=/etc/init.d
    STATEFILE=/var/log/retroclient.state

    if [ ! $LSBSYSTEM ]; then
        [ -f /etc/redhat-release ] && INITD=/etc/rc.d/init.d
    fi

    /bin/mv -f $CLIENTDIR/rcl $INITD
    ln -sf $INITD/rcl $CLIENTDIR/rcl 
    if [ ! -f $STATEFILE ]; then
        $CLIENTDIR/retroclient -setpass
    fi

    # Start the client as a daemon

    echo $STARTINGCLIENTMESSAGE
    RETROSPECT_HOME="$CLIENTDIR"
    export RETROSPECT_HOME
    $CLIENTDIR/rcl start &
    echo    
    sleep 1
    if [ -x /sbin/pidof ] && [ -z "$(/sbin/pidof retroclient)" ] || [ -z "$(ps -e | grep retroclient)" ]; then
        echo -e $CLIENTNOSTARTMESSAGE
    else
        echo $CLIENTSTARTEDMESSAGE
    fi
    if [ $UPGRADE ]; then
        echo $UPGRADESUCCESSMESSAGE
    elif [ $LSBSYSTEM ]; then
        # If not already installed, then install it.
        /usr/lib/lsb/install_initd /etc/init.d/rcl
    else
        if [ -d "/etc/rc.d/rc2.d" ] && [ ! -f "/etc/rc.d/rc2.d/S99retroclient" ]; then
            for Y in 2 3 5; do
                ln -s $CLIENTDIR/rcl /etc/rc.d/rc$Y.d/S99retroclient
            done
        elif [ ! -d "/etc/rc.d/rc2.d" ]; then
            echo -e $LINUXNORCMESSAGE
        fi
    fi

    # Give a friendly message to hit enter to close the window.

    echo
    if [ "$(ps -e | grep xterm)" ]; then
        echo -n $PRESSENTERMESSAGE
        read X
        if [ "$X" ]; then
            exit 0
        fi
    fi
    exit 0
else
    # This is not a supported operating system.  Bail out.

    echo
    echo $UNSUPPORTEDOSMESSAGE
    exit 0
fi

exit 0

